@@ -23,10 +23,10 @@ led = slcp(SERIAL_PORTS_MAP, LED_MAP)
 
 # Variables Declaration
 state = False
-r = 0
-g = 0
-b = 0
-brightness = 0
+r = 255
+g = 255
+b = 255
+brightness = 255
 effect = 0
 effector: led_effects.effect = None
 
@@ -98,16 +98,19 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
                     effector.stop_effect()
                     effect = 0
                     effector = None
+                    mqttclient.publish(MQTT_BASE_TOPIC+"/report/effect",
+                       led_effects.effects[effect]['name'])
                 led.turn_off()
                 state = 0
             elif payload == "on":
-                state = 1
-                if effect == 0:
-                    led.fill_led_with_color(
-                        r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
-                elif effect >= 2:
-                    effector = led_effects.effects[effect]['class'](
-                        frame_time=0.1, led=led, brightness=brightness)
+                if state != 1:
+                    state = 1
+                    if effect == 0:
+                        led.fill_led_with_color(
+                            r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
+                    elif effect >= 2:
+                        effector = led_effects.effects[effect]['class'](
+                            frame_time=0.1, led=led, brightness=brightness)
         mqttclient.publish(MQTT_BASE_TOPIC+"/report/state",
                        "on" if state else "off")
     elif topic == MQTT_BASE_TOPIC+"/control/brightness":
@@ -127,6 +130,8 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
             effector.stop_effect()
             effector = None
             effect = 0
+            mqttclient.publish(MQTT_BASE_TOPIC+"/report/effect",
+                       led_effects.effects[effect]['name'])
         try:
             [rtmp,gtmp,btmp] = payload.split(',')
             r = float(rtmp)
@@ -145,13 +150,16 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
         for i in range(len(led_effects.effects)):
             if led_effects.effects[i]['name'] == payload:
                 effect = i
+                if effect == 0:
+                    led.fill_led_with_color(
+                        r*brightness/255.0, g*brightness/255.0, b*brightness/255.0)
                 if effect >= 2 and state:
                     effector = led_effects.effects[i]['class'](
                         frame_time=0.1, led=led, brightness=brightness)
         mqttclient.publish(MQTT_BASE_TOPIC+"/report/effect",
                        led_effects.effects[effect]['name'])
     elif topic == MQTT_BASE_TOPIC+"/control/exit":
-        sys.exit(17)
+        sys.exit(0)
     #TODO Input Validation, 0<=data[0]<=num_leds
     elif topic == MQTT_BASE_TOPIC+"/control/program":
         if effect == 1:
@@ -161,8 +169,11 @@ def handle_mqtt_messages(client, userdata, msg: mqtt.MQTTMessage):
             led.show()
     elif topic == MQTT_BASE_TOPIC+"/control/requeststate":
         report_state()
+
 mqttclient.on_message = handle_mqtt_messages
 
+report_state()
+
 print("Initialization Completed!")
 
 mqttclient.loop_forever()
